@@ -25,6 +25,8 @@
 #include "memory.h"
 #include "random.h"
 #include "error.h"
+#include "config.h"
+#include "igraph_math.h"
 
 #include <assert.h>
 #include <string.h> 		/* memcpy & co. */
@@ -63,6 +65,11 @@ int igraph_indheap_init           (igraph_indheap_t* h, long int alloc_size) {
  return 0;  
 }
 
+int igraph_indheap_clear(igraph_indheap_t *h) {
+  h->end=h->stor_begin;
+  return 0;
+}
+
 /**
  * \ingroup indheap
  * \brief Initializes and build an indexed heap from a C array (constructor).
