@@ -22,7 +22,8 @@
 */
 
 /* The original version of this file was written by Pascal Pons
-   The original copyright notice follows here */
+   The original copyright notice follows here. The FSF address was
+   fixed by Tamas Nepusz */
 
 // File: walktrap.cpp
 //-----------------------------------------------------------------------------
@@ -41,7 +42,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+// 02110-1301 USA
 //-----------------------------------------------------------------------------
 // Author   : Pascal Pons 
 // Email    : pons@liafa.jussieu.fr
